---
Added: v2.0.0
Status: Active
---

# Comment list component

Shows a list of comments.

![ADF Comment List](../docassets/images/adf-comment-list.png)

## Basic Usage

Populate the comments in the component class:

```ts
import { CommentProcessModel } from '@alfresco/adf-core';

export class SomeComponent implements OnInit {

  comments: CommentProcessModel[] = [
    {
      id: 1,
      message: 'Comment number 1',
      created: new Date(),
      createdBy: {
        id: 1,
        email: 'john.doe@alfresco.com',
        firstName: 'John',
        lastName: 'Doe'
      },
    },
    {
      id: 2,
      message: 'Comment number 2',
      created: new Date(),
      createdBy: {
        id: 2,
        email: 'jane.doe@alfresco.com',
        firstName: 'Jane',
        lastName: 'Doe'
      },
    }
  ];

  onClickCommentRow(comment: CommentProcessModel) {
    console.log('Clicked row: ', comment);
  }
```

In the component template use the [comment list component](../core/comment-list.component.md):

```html
<adf-comment-list
    [comments]="comments"
    (clickRow)="onClickCommentRow($event)">
</adf-comment-list>
```

## Class members

### Properties

| Name | Type | Default value | Description |
| -- | -- | -- | -- |
| comments | [`CommentModel`](../../lib/core/models/comment.model.ts)`[]` |  | The comments data used to populate the list. |

### Events

| Name | Type | Description |
| -- | -- | -- |
| clickRow | [`EventEmitter`](https://angular.io/api/core/EventEmitter)`<`[`CommentModel`](../../lib/core/models/comment.model.ts)`>` | Emitted when the user clicks on one of the comment rows. |
